==> wireshark_4.4.13.orig.tar.bz2: wireshark-v4.4.13/resources/Acknowledgements.md <==
Dan Lasley <dlasley[AT]promus.com> gave permission for his `dumpit()` hex-dump routine to be used.

We use the exception module from [Kazlib](https://www.kylheku.com/~kaz/kazlib.html), a C library written by Kaz Kylheku <kaz[AT]kylheku.com>. Thanks go to him for his well-written library.

We use [Lua](https://www.lua.org/about.html) to extend Wireshark APIs with scripting capabilities. Lua is a powerful, efficient, lightweight, embeddable scripting language developed and maintained by a team at PUC-Rio.

We use [Lua BitOp](https://bitop.luajit.org), written by Mike Pall, for bitwise operations on numbers in Lua.

Snax <snax[AT]shmoo.com> gave permission to use the weak key detection code from [Airsnort](http://airsnort.shmoo.com).

IANA gave permission for their port-numbers file to be used.

We use the natural order string comparison algorithm, written by Martin Pool <mbp[AT]sourcefrog.net>.

Emanuel Eichhammer <support[AT]qcustomplot.com> granted permission to use [QCustomPlot](https://www.qcustomplot.com).

Some icons made by [Freepik](https://www.freepik.com) from <https://www.flaticon.com>.

Insecure.Com LLC ("The Nmap Project") has granted the Wireshark Foundation permission to distribute [Npcap](https://npcap.com) with our Windows installers.

We use the overflow-safe math functions from the [portable snippets](https://github.com/nemequ/portable-snippets) repository.

We use the [Lrexlib](https://github.com/rrthomas/lrexlib) Lua library, specifically the PCRE2 flavour, to provide a regular expression API for Lua.

The code for our `strptime()` implementation is from [NetBSD](https://www.netbsd.org/).

==> wireshark_4.6.3.orig.tar.bz2: wireshark-v4.6.3/resources/Acknowledgements.md <==
Dan Lasley <dlasley[AT]promus.com> gave permission for his `dumpit()` hex-dump routine to be used.

We use the exception module from [Kazlib](https://www.kylheku.com/~kaz/kazlib.html), a C library written by Kaz Kylheku <kaz[AT]kylheku.com>. Thanks go to him for his well-written library.

We use [Lua](https://www.lua.org/about.html) to extend Wireshark APIs with scripting capabilities. Lua is a powerful, efficient, lightweight, embeddable scripting language developed and maintained by a team at PUC-Rio.

We use [Lua BitOp](https://bitop.luajit.org), written by Mike Pall, for bitwise operations on numbers in Lua.

Snax <snax[AT]shmoo.com> gave permission to use the weak key detection code from [Airsnort](http://airsnort.shmoo.com).

IANA gave permission for their port-numbers file to be used.

We use the natural order string comparison algorithm, written by Martin Pool <mbp[AT]sourcefrog.net>.

Emanuel Eichhammer <support[AT]qcustomplot.com> granted permission to use [QCustomPlot](https://www.qcustomplot.com).

Some icons made by [Freepik](https://www.freepik.com) from <https://www.flaticon.com>.

Insecure.Com LLC ("The Nmap Project") has granted the Wireshark Foundation permission to distribute [Npcap](https://npcap.com) with our Windows installers.

We use the [jtckdint](https://github.com/jart/jtckdint) implementation of C23 checked arithmetic written by Justine Tunney <jtunney[AT]gmail.com>.

We use the [Lrexlib](https://github.com/rrthomas/lrexlib) Lua library, specifically the PCRE2 flavour, to provide a regular expression API for Lua.

The code for our `strptime()` implementation is from [NetBSD](https://www.netbsd.org/).

We use the [dtoa](https://www.netlib.org/fp/) implementation written by David M. Gay.
